import os
import sys
from datetime import datetime, time, timedelta

from dateutil.relativedelta import relativedelta


def get_curr_month():
    now = datetime.now()
    if now.time() < time(13, 0):
        now -= timedelta(days=1)
    return now.strftime("%Y-%m")


def get_curr_day():
    return datetime.now().strftime("%Y-%m-%d")


def get_one_day_before():
    return (datetime.now().date() - timedelta(days=1)).strftime("%Y-%m-%d")


def get_first_day_month():
    current_date = datetime.now().date()
    first_day_of_month = current_date.replace(day=1)
    return first_day_of_month.strftime("%Y-%m-%d")


# 计算两个时间差值 返回值秒
def get_difference(time_str1, time: datetime) -> float:
    time1 = datetime.strptime(time_str1, '%Y-%m-%d %H:%M:%S')
    time_difference = time - time1
    return abs(time_difference.total_seconds())


def resource_path(relative_path):
    """ 获取资源的绝对路径。用于访问打包后的资源文件。 """
    if hasattr(sys, '_MEIPASS'):
        # 如果程序被打包，则使用临时目录
        base_path = sys._MEIPASS
    else:
        # 如果程序未被打包，则使用当前目录
        base_path = os.path.abspath(".")

    return os.path.join(base_path, relative_path)


def get_last_day_of_last_month():
    last_day_of_last_month = datetime.now().replace(day=1) - relativedelta(days=1)
    return last_day_of_last_month.strftime("%Y-%m-%d")


def get_first_day_of_last_month():
    last_day_of_last_month = datetime.now().replace(day=1) - relativedelta(days=1)
    first_day_of_last_month = last_day_of_last_month.replace(day=1)
    return first_day_of_last_month.strftime("%Y-%m-%d")


def get_first_day_by_str(date_str):
    # 解析日期字符串
    date = datetime.strptime(date_str, "%Y-%m-%d")

    # 获取该月的第一天
    first_day = date.replace(day=1)

    return first_day.strftime("%Y-%m-%d")


def convert_data(data):
    """
    尝试将数据转换为最合适的类型。
    """
    # 尝试转换为浮点数
    try:
        float_data = float(data)
        # 如果转换后的数据和原始数据相同，则尝试转换为整数
        if float_data.is_integer():
            return int(float_data)
        return float_data
    except ValueError:
        pass

    # 尝试转换为日期时间
    for fmt in ("%Y-%m-%d %H:%M:%S", "%Y-%m-%d", "%H:%M:%S"):
        try:
            return datetime.strptime(data, fmt)
        except ValueError:
            pass

    # 如果所有转换都失败，保留为字符串
    return data
