import time
from concurrent.futures.thread import ThreadPoolExecutor
from typing import List

from loguru import logger
from util import get_curr_day

from src.core.constant import BOT_TOKEN, GROUP_ID
from src.core.message_client import send_message
from src.entity.account import Account
from src.entity.banner_info import BannerInfo, get_banner_info
from src.entity.database import db
from src.entity.member import get_today_new_member_list
from src.entity.pay_record import get_latest_deposit_user
from src.entity.user import User


def query_banner_info(account: Account):
    last_banner_info = get_banner_info(account)
    while True:
        try:
            date = get_curr_day()
            banner_info = get_banner_info(account)
            logger.debug(f'{account.name}请求成功：{banner_info}')
            logger.info(
                f'{time.strftime("%Y-%m-%d %H:%M:%S")} {account.name}：注册：{banner_info.registerMembers},首存：{banner_info.firstDepositNum},负盈利：{banner_info.netWinLose},有效：{banner_info.effectiveNew},活跃：{banner_info.activeMembers}')
            if banner_info.registerMembers > last_banner_info.registerMembers:
                register_count = banner_info.registerMembers - last_banner_info.registerMembers
                logger.debug(f'新注册用户数为 {register_count}')
                members = get_today_new_member_list(account, register_count)
                if members is not None:
                    names = ','.join([f'`{member.name}`' for member in members])
                else:
                    names = 'unknown'
                msg = f'👏 {account.name} 注册:{register_count} 用户: {names} 总数: {banner_info.registerMembers}'
                send_message(BOT_TOKEN, GROUP_ID, msg)
                logger.info(f'发送的消息: {msg}')

                last_banner_info = banner_info

            if banner_info.firstDepositNum > last_banner_info.firstDepositNum:
                count = banner_info.firstDepositNum - last_banner_info.firstDepositNum
                member_details_list = get_latest_deposit_user(account, count)
                msg = '\n'.join(
                    [f"用户: `{member_detail.name}`, 首存金额: *{member_detail.deposit}*" for member_detail in
                     member_details_list])
                send_message(BOT_TOKEN, GROUP_ID,
                             f'🎉 {account.name} 首存:{count} {msg} 总数:*{banner_info.firstDepositNum}*')
                logger.info(f'发送的消息: {msg}')

                last_banner_info = banner_info
            time.sleep(60)
        except Exception as e:
            send_message(BOT_TOKEN, GROUP_ID, str(e))
            logger.exception(f'发生未知错误:{e} ')
            time.sleep(10)
            return query_banner_info(account)


def get_banner_info_by_user(user: User) -> List[BannerInfo]:
    with ThreadPoolExecutor(max_workers=len(user.accounts)) as executor:
        futures = [executor.submit(get_banner_info, account) for account in user.accounts]
        return [future.result() for future in futures]

