from PyQt6.QtCore import Qt
from PyQt6.QtGui import QFont, QIcon, QPixmap
from PyQt6.QtWidgets import QHBoxLayout, QLabel, QToolButton, QWidget


class CustomTitleBar(QWidget):
    def __init__(self, parent):
        super().__init__(parent)
        self.parent = parent
        self.setup_ui()
        self.mousePressed = False

    def setup_ui(self):
        self.layout = QHBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)  # 设置布局的边距为0
        self.layout.setSpacing(0)  # 设置按钮之间的间距为0

        # 创建图标 QLabel
        self.iconLabel = QLabel(self)
        self.iconLabel.setFixedSize(32, 32)  # 设置图标大小
        iconPixmap = QPixmap('icons:icon.png').scaled(24, 24, Qt.AspectRatioMode.KeepAspectRatio)
        self.iconLabel.setPixmap(iconPixmap)
        self.layout.addWidget(self.iconLabel)  # 添加图标到布局

        # 创建标题 QLabel
        font = QFont()
        font.setPointSize(11)
        self.titleLabel = QLabel("zayac的小工具")
        self.titleLabel.setFont(font)
        self.titleLabel.setAlignment(Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignVCenter)
        self.layout.addWidget(self.titleLabel, 1)

        # 使用图标按钮并应用样式
        self.stayOnTopButton = QToolButton()
        self.stayOnTopButton.setIcon(QIcon('icons:top.svg'))
        self.stayOnTopButton.setFixedSize(32, 32)  # 设置按钮的固定大小
        self.stayOnTopButton.setCheckable(True)
        self.stayOnTopButton.clicked.connect(self.toggle_stay_on_top)
        self.layout.addWidget(self.stayOnTopButton)

        # 设置其他按钮
        self.minimizeButton = QToolButton()
        self.minimizeButton.setIcon(QIcon('icons:min.svg'))
        self.minimizeButton.setFixedSize(32, 32)
        self.minimizeButton.clicked.connect(self.parent.showMinimized)
        self.layout.addWidget(self.minimizeButton)

        self.maximizeButton = QToolButton()
        self.maximizeButton.setIcon(QIcon('icons:max.svg'))
        self.maximizeButton.setFixedSize(32, 32)
        self.maximizeButton.clicked.connect(self.toggle_maximize)
        self.layout.addWidget(self.maximizeButton)

        self.closeButton = QToolButton()
        self.closeButton.setIcon(QIcon('icons:close.svg'))
        self.closeButton.setFixedSize(32, 32)
        self.closeButton.clicked.connect(self.parent.close)
        self.closeButton.setObjectName("closeButton")
        self.layout.addWidget(self.closeButton)

        # 在创建按钮后立即设置样式表

        self.setLayout(self.layout)

    def mousePressEvent(self, event):
        self.mousePressed = True
        self.mousePos = event.globalPosition().toPoint()

    def mouseMoveEvent(self, event):
        if self.mousePressed:
            self.parent.move(self.parent.pos() + (event.globalPosition().toPoint() - self.mousePos))
            self.mousePos = event.globalPosition().toPoint()

    def mouseReleaseEvent(self, event):
        self.mousePressed = False

    def toggle_stay_on_top(self):
        if self.stayOnTopButton.isChecked():
            self.parent.setWindowFlags(self.parent.windowFlags() | Qt.WindowType.WindowStaysOnTopHint)
        else:
            self.parent.setWindowFlags(self.parent.windowFlags() & ~Qt.WindowType.WindowStaysOnTopHint)
        self.parent.show()  # 重新显示窗口以应用新的窗口标志

    def enterEvent(self, event):
        self.parent.reset_cursor_style()  # 通知主窗口重置鼠标样式

    def leaveEvent(self, event):
        self.parent.reset_cursor_style()  # 通知主窗口重置鼠标样式

    def toggle_maximize(self):
        if self.parent.isMaximized():
            self.parent.showNormal()
        else:
            self.parent.showMaximized()
